function GenOptPlots()

beta = [];
alpha = [];
load('EEData_6D.mat');

% % \rho  and \rho' are equal in the simulations
[u,v,w,x,y,z] = ndgrid(rodB,beta,alpha,toudB,LambdaPrime,P_dBm);
rodB_i = linspace(min(rodB),max(rodB),100);
beta_i = linspace(min(beta),max(beta),30);
alpha_i = linspace(min(alpha),max(alpha),30);
LambdaPrime_i = linspace(min(LambdaPrime),max(LambdaPrime),60);
[ui,vi,wi,xi,yi,zi] = ndgrid(rodB_i,beta_i,alpha_i,toudB,LambdaPrime_i,P_dBm);
EE = EE*7^2;

% 6 dimensional interpolation
EE_smooth = interpn(u,v,w,x,y,z,EE,ui,vi,wi,xi,yi,zi,'spline');

% Find maximum EE
EE_opt = squeeze(max(squeeze(max(squeeze(max(EE_smooth))))));

% Find optimum alpha
[~, idx_alpha_opt] = max(squeeze(max(squeeze(max(EE_smooth)))));
idx_alpha_opt = squeeze(idx_alpha_opt);
alpha_opt = alpha_i(idx_alpha_opt);

% Find optimum beta
x = permute(EE_smooth,[1 3 2 4 5 6]);
[~, idx_beta_opt] = max(squeeze(max(squeeze(max(x)))));
idx_beta_opt = squeeze(idx_beta_opt);
beta_opt = beta_i(idx_beta_opt);

% Find optimum rho
x = permute(EE_smooth,[2 3 1 4 5 6]);
[~, idx_ro_opt] = max(squeeze(max(squeeze(max(x)))));
idx_ro_opt = squeeze(idx_ro_opt);
ro_opt = rodB_i(idx_ro_opt);

% Maximum EE v/s PBS density plots
figure(1);
clf;
subplot(2,1,1);
plot(LambdaPrime_i(:), EE_opt(1,:,1),'-');
hold on;
plot(LambdaPrime_i(:), EE_opt(2,:,1),'--r');
plot(LambdaPrime_i(:), EE_opt(3,:,1),':g');
hold off;
ylabel('maximum EE');
legend('\tau = 0 dB','\tau = 6 dB','\tau = 12 dB','Location','Best');
title('P_{pic} = 30 dBm');
subplot(2,1,2);
plot(LambdaPrime_i(:), EE_opt(1,:,2),'-');
hold on;
plot(LambdaPrime_i(:), EE_opt(2,:,2),'r--');
plot(LambdaPrime_i(:), EE_opt(3,:,2),':g');
hold off;
xlabel('PBS density / MBS desity (\lambda\prime/\lambda)');
ylabel('maximum EE');
legend('\tau = 0 dB','\tau = 6 dB','\tau = 12 dB','Location','Best');
title('P_{pic} = 10 dBm');

% Optimum alpha v/s PBS density plots
figure(2);
clf;
subplot(2,1,1);
plot(LambdaPrime_i(:), alpha_opt(1,:,1),'-');
hold on;
plot(LambdaPrime_i(:), alpha_opt(2,:,1),'--r');
plot(LambdaPrime_i(:), alpha_opt(3,:,1),':g');
hold off;
ylabel('optimum  \alpha');
legend('\tau = 0 dB','\tau = 6 dB','\tau = 12 dB','Location','Best');
title('P_{pic} = 30 dBm');
ylim([0 1]);
subplot(2,1,2);
plot(LambdaPrime_i(:), alpha_opt(1,:,2),'-');
hold on;
plot(LambdaPrime_i(:), alpha_opt(2,:,2),'--r');
plot(LambdaPrime_i(:), alpha_opt(3,:,2),':g');
hold off;
xlabel('PBS density / MBS desity (\lambda\prime/\lambda)');
ylabel('optimum  \alpha');
legend('\tau = 0 dB','\tau = 6 dB','\tau = 12 dB','Location','Best');
title('P_{pic} = 10 dBm');
ylim([0 1]);

% Optimum beta v/s PBS density plots
figure(3);
clf;
subplot(2,1,1);
plot(LambdaPrime_i(:), beta_opt(1,:,1),'-');
hold on;
plot(LambdaPrime_i(:), beta_opt(2,:,1),'--r');
plot(LambdaPrime_i(:), beta_opt(3,:,1),':g');
hold off;
ylabel('optimum  \beta');
legend('\tau = 0 dB','\tau = 6 dB','\tau = 12 dB','Location','Best');
ylim([0 1]);
title('P_{pic} = 30 dBm');
subplot(2,1,2);
plot(LambdaPrime_i(:), beta_opt(1,:,2),'-');
hold on;
plot(LambdaPrime_i(:), beta_opt(2,:,2),'r--');
plot(LambdaPrime_i(:), beta_opt(3,:,2),':g');
hold off;
xlabel('PBS density / MBS desity (\lambda\prime/\lambda)');
ylabel('optimum  \beta');
legend('\tau = 0 dB','\tau = 6 dB','\tau = 12 dB','Location','Best');
ylim([0 1]);
title('P_{pic} = 30 dBm');

% Optimum rho v/s PBS density plots
figure(4);
clf;
subplot(2,1,1);
plot(LambdaPrime_i(:), ro_opt(1,:,1),'-');
hold on;
plot(LambdaPrime_i(:), ro_opt(2,:,1),'--r');
plot(LambdaPrime_i(:), ro_opt(3,:,1),':g');
hold off;
ylabel('optimum  \rho');
legend('\tau = 0 dB','\tau = 6 dB','\tau = 12 dB','Location','Best');
title('P_{pic} = 30 dBm');
subplot(2,1,2);
plot(LambdaPrime_i(:), ro_opt(1,:,2),'-');
hold on;
plot(LambdaPrime_i(:), ro_opt(2,:,2),'r--');
plot(LambdaPrime_i(:), ro_opt(3,:,2),':g');
hold off;
xlabel('PBS density / MBS desity (\lambda\prime/\lambda)');
ylabel('optimum  \rho');
legend('\tau = 0 dB','\tau = 6 dB','\tau = 12 dB','Location','Best');
title('P_{pic} = 30 dBm');

end