function [AreaSE, AreaPwrConsmp] = EnergyEfficiency_Sim(l,l1,beta,alpha,toudB,rodB,ro1dB)

% Following are the Input parameters
Nrun = 10;
PdBm = 46;          % Macro Tx power in dBm
P1dBm = 10;         % Macro Tx power in dBm
KdB = -11;          % Attenuation due to geometrical parameters of antennas
K1dB = -11;         % Attenuation due to geometrical parameters of antennas
lu = 200;
Dmin_macro = 0.035; % Minimum distance between eNB and UE (in Kms)
Dmin_pico = 0.010;  % Minimum distance between PeNB and UE (in Kms)
MaxDist = 10;       % Distance of the side of the simulation area (square)
% End of the input parameters

Pm = 10^(PdBm/10)/1000 * 10^(KdB/10);
Pp = 10^(P1dBm/10)/1000 * 10^(K1dB/10);
Ptxm = 10^(PdBm/10)/1000;
Ptxp = 10^(P1dBm/10)/1000;
tou = 10^(toudB/10);
ro = 10^(rodB/10);
ro1 = 10^(ro1dB/10);

MaxUEDist = 0.7*MaxDist;      % Distance of the side of UE location area (square)
Nm = round(l*MaxDist^2);
Np = round(l1*MaxDist^2);
Nue = round(lu*MaxUEDist^2);

AreaSE = zeros(Nrun,1);
AreaPwrConsmp = AreaSE;
for nn = 1:Nrun
    % Initially generate random MBS, PBS and UE location coordinates
    % within a given simulation area
    Xm = MaxDist*(rand(Nm,1)-0.5);
    Ym = MaxDist*(rand(Nm,1)-0.5);
    Xp = MaxDist*(rand(Np,1)-0.5);
    Yp = MaxDist*(rand(Np,1)-0.5);
    Xue = MaxUEDist*(rand(Nue,1)-0.5);
    Yue = MaxUEDist*(rand(Nue,1)-0.5);

    % Coordinates of all the macrocell and picocell nodes (the third column
    % indicates whether it is a PeNB (:1) or eNB (:2) )
    All_Node_Coor = [Xp Yp ones(size(Xp)); Xm Ym 2*ones(size(Xm))];

    % Find distances between every UE from every BS
    [Xpm_mat Xue_mat] = meshgrid(All_Node_Coor(:,1),Xue);
    [Ypm_mat Yue_mat] = meshgrid(All_Node_Coor(:,2),Yue);
    Dmpu = sqrt((Xpm_mat-Xue_mat).^2 + (Ypm_mat-Yue_mat).^2);
    clear All_Node_Coor Xpm_mat Ypm_mat Xue_mat Yue_mat;

    % Find MOI and POI for every UE
    [moi_dist,idx_moi] = min(Dmpu(:,(length(Xp)+1):end),[],2);
    idx_moi = idx_moi + length(Xp);
    [poi_dist,idx_poi] = min(Dmpu(:,1:length(Xp)),[],2);

    % Exclude the UEs which do not satisfy the min. distance contraints
    idx = (moi_dist < Dmin_macro) | (poi_dist < Dmin_pico);
    Xue(idx) = [];
    Dmpu(idx,:) = [];
    idx_moi(idx) = [];
    idx_poi(idx) = [];

%     Yue(idx) = [];
%     % Plot the eNB and PeNB layout
%     plot(Xm,Ym,'or',Xp,Yp,'.',Xue,Yue,'xg');
%     xlabel('X-axis distance (Kms)');
%     ylabel('Y-axis distance (Kms)');
%     legend('Macro nodes','Pico nodes','UEs');

    % Calculte Received powers at all the UEs from every BS
    Ppm_mat = [Pp*ones(length(Xue),length(Xp)) Pm*ones(length(Xue),length(Xm))];
    Pr_usf = exprnd(Ppm_mat,size(Ppm_mat))./(Dmpu*1e3).^4;
    mult = binornd(1,beta,1,length(Xm));
    mult(mult == 0) = alpha;
    Pr = Pr_usf.*[ones(length(Xue),length(Xp)) repmat(mult,length(Xue),1)];
    clear Xue Yue Dmpu Ppm_mat;

    % find received powers from MOI and POI for each UE
    P_mac = Pr(sub2ind(size(Pr),(1:length(idx_moi))',idx_moi));
    P_pic = Pr(sub2ind(size(Pr),(1:length(idx_poi))',idx_poi));
    P_mac_usf = Pr_usf(sub2ind(size(Pr_usf),(1:length(idx_moi))',idx_moi));

    % Calculate total interference at each UE except MOI/POI
    Z = sum(Pr,2) - P_mac - P_pic;
    clear Pr_usf Pr;

    % Calculte Macro and pico SIRs
    SIR_mac_usf = P_mac_usf./(P_pic + Z);
    SIR_mac_csf = alpha*SIR_mac_usf;
    SIR_pic_usf = P_pic./(P_mac_usf + Z);
    SIR_pic_csf = P_pic./(alpha*P_mac_usf + Z);

    if(alpha == 0)
        idx_mue_usf = SIR_mac_usf > tou*SIR_pic_usf;
    else
        idx_mue_usf = (SIR_mac_usf > tou*SIR_pic_usf) & (SIR_mac_usf <= ro);
        idx_mue_csf = (SIR_mac_usf > tou*SIR_pic_usf) & (SIR_mac_usf > ro);
    end
    idx_pue_usf = (SIR_mac_usf <= tou*SIR_pic_usf) & (SIR_pic_usf > ro1);
    idx_pue_csf = (SIR_mac_usf <= tou*SIR_pic_usf) & (SIR_pic_usf <= ro1);

    % USF MUEs
    idx_moi_usf = idx_moi(idx_mue_usf);
    SIR_mac_usf = SIR_mac_usf(idx_mue_usf);
    hm_usf = tabulate([-1; idx_moi_usf]);
    hm_usf(1,:) = [];
    Nmue_usf = hm_usf(:,2);
    SE_tot = 0;
    for xx = 1:length(Nmue_usf)
        idx = idx_moi_usf == hm_usf(xx,1);
        SE_tot = SE_tot + beta*sum(log2(1+SIR_mac_usf(idx)))/Nmue_usf(xx);
    end

    if(alpha ~= 0)
        % CSF MUEs
        idx_moi_csf = idx_moi(idx_mue_csf);
        SIR_mac_csf = SIR_mac_csf(idx_mue_csf);
        hm_csf = tabulate([-1; idx_moi_csf]);
        hm_csf(1,:) = [];
        Nmue_csf = hm_csf(:,2);
        for xx = 1:length(Nmue_csf)
            idx = idx_moi_csf == hm_csf(xx,1);
            SE_tot = SE_tot + (1-beta)*sum(log2(1+SIR_mac_csf(idx)))/Nmue_csf(xx);
        end
    end
    
    % USF PUEs
    idx_poi_usf = idx_poi(idx_pue_usf);
    SIR_pic_usf = SIR_pic_usf(idx_pue_usf);
    hp_usf = tabulate([-1; idx_poi_usf]);
    hp_usf(1,:) = [];
    Npue_usf = hp_usf(:,2);
    for xx = 1:length(Npue_usf)
        idx = idx_poi_usf == hp_usf(xx,1);
        SE_tot = SE_tot + beta*sum(log2(1+SIR_pic_usf(idx)))/Npue_usf(xx);
    end
    
    % CSF PUEs
    idx_poi_csf = idx_poi(idx_pue_csf);
    SIR_pic_csf = SIR_pic_csf(idx_pue_csf);
    hp_csf = tabulate([-1; idx_poi_csf]);
    hp_csf(1,:) = [];
    Npue_csf = hp_csf(:,2);
    for xx = 1:length(Npue_csf)
        idx = idx_poi_csf == hp_csf(xx,1);
        SE_tot = SE_tot + (1-beta)*sum(log2(1+SIR_pic_csf(idx)))/Npue_csf(xx);
    end
    AreaSE(nn) = SE_tot/MaxUEDist^2;
    
    % Count the number of BSs within the simulation are of UEs
    idx = Xm<=(MaxUEDist/2) & Xm>=(-MaxUEDist/2);
    Xm = Xm(idx); Ym = Ym(idx);
    idx = Ym<=(MaxUEDist/2) & Ym>=(-MaxUEDist/2);
    Xm = Xm(idx);
    idx = Xp<=(MaxUEDist/2) & Xp>=(-MaxUEDist/2);
    Xp = Xp(idx); Yp = Yp(idx);
    idx = Yp<=(MaxUEDist/2) & Yp>=(-MaxUEDist/2);
    Xp = Xp(idx);
    
    AreaPwrConsmp(nn) = Ptxm*length(Xm)+ Ptxp*length(Xp);
end

AreaSE = mean(AreaSE);
AreaPwrConsmp = mean(AreaPwrConsmp);

end